@@ -1,4 +1,4 @@
-package Dist::Zilla::PluginBundle::RJBS 5.035;
+package Dist::Zilla::PluginBundle::RJBS 5.036;
 # ABSTRACT: BeLike::RJBS when you build your dists
 
 use Moose;
@@ -65,7 +65,7 @@ use Dist::Zilla::PluginBundle::Basic;
 use Dist::Zilla::PluginBundle::Filter;
 use Dist::Zilla::PluginBundle::Git;
 
-package Dist::Zilla::Plugin::RJBSMisc 5.035 {
+package Dist::Zilla::Plugin::RJBSMisc 5.036 {
   use Moose;
   with 'Dist::Zilla::Role::BeforeBuild',
        'Dist::Zilla::Role::AfterBuild',
@@ -354,7 +354,14 @@ sub configure ($self) {
     ],
   });
 
-  $self->add_plugins('Git::Contributors');
+  $self->add_plugins(
+    [ 'Git::Contributors' => {
+      remove => [
+        'claude@anthropic.com',
+        'noreply@anthropic.com',
+      ],
+    } ]
+  );
 }
 
 __PACKAGE__->meta->make_immutable;
@@ -373,7 +380,7 @@ Dist::Zilla::PluginBundle::RJBS - BeLike::RJBS when you build your dists
 
 =head1 VERSION
 
-version 5.035
+version 5.036
 
 =head1 DESCRIPTION
 
@@ -452,7 +459,7 @@ Ricardo Signes <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2025 by Ricardo Signes.
+This software is copyright (c) 2026 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
